summaryrefslogtreecommitdiff
path: root/src/gui/window.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/window.h')
-rw-r--r--src/gui/window.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/gui/window.h b/src/gui/window.h
index 95db2f4b..2986bad1 100644
--- a/src/gui/window.h
+++ b/src/gui/window.h
@@ -141,10 +141,12 @@ class Window : public gcn::Window, public ConfigListener
void scheduleDelete();
/**
* Window dragging. This method also makes sure the window is not
* dragged outside of the screen.
*/
+ void mousePress(int x, int y, int button);
void mouseMotion(int mx, int my);
+ void mouseRelease(int x, int y, int button);
/**
* Called when an config option changes.
@@ -157,6 +159,8 @@ class Window : public gcn::Window, public ConfigListener
int snapSize; /**< Snap distance to window edge */
bool modal; /**< Window is modal */
bool resizeable; /**< Window can be resized */
+ bool winXResizing; /**< Window being resized in X direction */
+ bool winYResizing; /**< Window being resized in Y direction */
int minWinWidth; /**< Minimum window width */
int minWinHeight; /**< Minimum window height */
int maxWinWidth; /**< Maximum window width */
@@ -141,10 +141,12 @@ class Window : public gcn::Window, public ConfigListener
void scheduleDelete();
/**
- * Window dragging. This method also makes sure the window is not
- * dragged outside of the screen.
+ * Window dragging and resizing. These methods also makes sure the
+ * window is not dragged/resized outside of the screen.
*/